msuchy: Tito was a plush toy and mascot of Red Hat Network (RHN)_team. Later when we opensourced Satellite as the Spacewalk project we created this project. And by that time Tito was already missing for some time. So in honor of our mascot we decided to name this project Tito.

@jmrodri: so it goes back even further. I was told a story about some sales folks asking the RHN folks for features. Someone on IRC, said "oh tito is working on that". They thought there was an actual person name, Tito. So it became a joke that things that we could never get to will be done by "Tito" :) (at least that's how I remember the story going).

So we tried to keep Tito alive. First came the stuffed animal in this PR. We had a team building event at a local arcade. We pooled our tickets together to get the purple animal. We named him Tito.

This project was named tito precisely to keep the legend going. And in case you didn't know, the Spaceman from Spacewalk is also named Tito.
